%bcond_with base_python

%define python_build_version 3.9
%define __python %{_bindir}/python%{python_build_version}

%if %{with base_python}
%define python_suffix %{expand:%%{lua: str='%{python_build_version}'; print(str:sub(1, 1))}}
%else
%define python_suffix %{expand:%%{lua: str='%{python_build_version}'; print(str:sub(1, 1) .. str:sub(3,-1))}}
%endif

%define pypi_name scipy

Name: python%{python_suffix}-%{pypi_name}
Version: 1.7.3
Release: 1
License: BSD-3-CLAUSE
Summary: Scientific Library for Python
Url: https://www.scipy.org/

Source0: https://github.com/scipy/scipy/releases/download/v%{version}/scipy-%{version}.tar.gz

BuildRequires: blas-devel >= 3.8.0
BuildRequires: cblas-devel >= 3.8.0
BuildRequires: lapack-devel >= 3.8.0
BuildRequires: lapacke-devel >= 3.8.0
BuildRequires: gcc-gfortran
BuildRequires: python%{python_suffix}-devel
BuildRequires: python%{python_suffix}-pip
BuildRequires: python%{python_suffix}-numpy > 1.15.0
BuildRequires: python%{python_suffix}-cython >= 0.29.24
BuildRequires: python%{python_suffix}-pybind11
BuildRequires: python%{python_suffix}-pythran

Requires: python%{python_suffix}-numpy > 1.15.0

%description
SciPy (pronounced “Sigh Pie”) is open-source software for mathematics, science,
and engineering. The SciPy library depends on NumPy, which provides convenient
and fast N-dimensional array manipulation. The SciPy library is built to work
with NumPy arrays, and provides many user-friendly and efficient numerical
routines such as routines for numerical integration and optimization. Together,
they run on all popular operating systems, are quick to install, and are free of
charge. NumPy and SciPy are easy to use, but powerful enough to be depended upon
by some of the world’s leading scientists and engineers.

%prep

%setup -q -n %{pypi_name}-%{version}

%build
export CC="gcc -fPIC"
export LDFLAGS="-pthread -Wl,-brtl"
# define LINUX_SOURCE_COMPAT to prevent AIX sys/timer.h from defining func_data
# as a t_union.data. In the scipy source func_data is used as a variable name
# therefore causing conflicts and leading to strange compile errors.
export CFLAGS="-pthread -D_LINUX_SOURCE_COMPAT $RPM_OPT_FLAGS"
%py_build_wheel

%install

%py_install_wheel %{pypi_name}-%{version}-cp%{python_version_nodots}-cp%{python_version_nodots}-os400_powerpc64.whl

sed -i 's|pip|rpm|g' %{buildroot}%{python_sitelib}/*.dist-info/INSTALLER

%files
%defattr(-, qsys, *none)

%license LICENSE.txt

%{python_sitelib}/scipy*

%changelog
* Thu Dec 02 2021 Abdirahim Musse <abdirahim.musse@ibm.com> - 1.7.3
- Update to 1.7.3
- Drop python39-scipy-NAN.patch becuase its now upstreamed
- Drop python39-scipy-ccallback.patch which was only for IBM i version <= 7.1

* Tue Jun 22 2021 Kevin Adler <kadler@us.ibm.com> - 1.1.0
- Port to Python 3.9
- Use macros from python-rpm-macros

* Fri Feb 05 2021 Kevin Adler <kadler@us.ibm.com>
- Use correct fortran buildrequires

* Thu Jan 17 2019 - Xu Meng <mengxumx@cn.ibm.com>
- change to use shared blas/lapack libs (#109)

* Thu Jan 03 2019 - Kevin Adler <kadler@us.ibm.com>
- Ensure necessary dependencies are listed
- Update description and use SPDX license

* Sun Aug 05 2018 - Kevin Adler <kadler@us.ibm.com>
- Set INSTALLER to be "rpm" instead of "pip"
- Add --no-index to pip, so it doesn't attempt to connect to the internet

* Fri Aug 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Clean up

* Thu Aug 02 2018 - Kevin Adler <kadler@us.ibm.com>
- Remove unneeded setuptools and wheel build requirements

* Fri Jul 13 2018 - Xu Meng <mengxumx@cn.ibm.com>
- build scipy from source

* Fri Jun 22 2018 - Xu Meng <mengxumx@cn.ibm.com>
- fix directory conflict issue

* Fri Jun 22 2018 - Xu Meng <mengxumx@cn.ibm.com>
- Add scipy for machine learning
